Sending public/private messages between users - My site
Description: Like most forums and communities, you should have the ability to private message a user or leave a public visitor message on their public 'wall'. It would just give a more of a sense of community.
Keywords: ,Askbot,forum,community

First time here? Check out the FAQ!

Hi there! Please sign in help
English ▼
tags users badges

| ALL UNANSWERED |  | Ask Your Question

10

# Sending public/private messages between users

- feature-request
- messaging

asked 2010-04-08 23:47:24 -0500

thekooliest09
101 ●2 ●3 ●3

updated 2012-08-25 11:55:23 -0500

todofixthis
1242 ●35 ●28 ●50

Like most forums and communities, you should have the ability to private message a user or leave a public visitor message on their public 'wall'. It would just give a more of a sense of community.

edit retag flag offensive close merge delete

## Comments

Thanks for the input! We'll have to put this one off for the later becase now we have to focus on the core features - admin interface, login system and the ease of installation and upgrades.
Evgeny ( 2010-04-09 11:09:03 -0500 )edit
also the basic on-screen notifiation system about new responses is still missing - this one will be done soon.
Evgeny ( 2010-04-09 11:19:49 -0500 )edit
What is the status on this? I think, atleast for moderators/admins, we need to be able to interact in private with a user to warn them or between admins for discussing changes
mether ( 2011-06-25 19:56:15 -0500 )edit
1
https://github.com/fitoria/askbot-devel/tree/postman, not merged yet into the trunk. There is a way to send email to users in the "moderation" tab on their profiles, but it is a simple email only feature.
Evgeny ( 2011-06-25 20:20:59 -0500 )edit
Typically moderators have a hidden sub-forum for group discussions that discuss things that need to be private like the question of banning a particular user. I wonder if something like that is possible here
mether ( 2011-06-25 20:29:19 -0500 )edit
add a comment see more comments

## 1 answer

Sort by » oldest newest most voted
6

answered 2012-05-03 09:19:55 -0500

todofixthis
1242 ●35 ●28 ●50

updated 2012-10-10 23:03:36 -0500

+1 This would be an excellent feature to keep experts on a site; not everyone gets a thrill out of answering questions, but high-karma users would be able to use this feature to network and gain [additional] value.

I would suggest a few requirements, though:

- Users should have the ability to specify that they only want users with a minimum amount of karma to be able to message them (e.g., experts might only want to network with other experts).
- Users should have the ability to add usernames to a block list ("blacklist") if they do not (or no longer) want to receive messages from those other users.
  - Alternatively, users should have the option to switch to "whitelist" mode where only the usernames they list will be permitted to message them.
- A minimal amount of karma should be required before a user can send any private messages (to prevent spam and other forms of abuse).

Having a public wall would be interesting, although the profile screen is already so busy, I'm not sure where it would go!

edit flag offensive delete link more
add a comment

## Your Answer

Please start posting anonymously - your entry will be published after you log in or create a new account.

Add Answer

[hide preview]
community wiki (karma is not awarded & many others can edit wiki post)

## Question Tools

3 followers

## Stats

Asked: 2010-04-08 23:47:24 -0500

Seen: 962 times

Last updated: Oct 10 '12

## Related questions

How to add private messaging to askbot, like django-postman?

Should a minor edit bring a Q&A back to the top of the sort order?

support for Mozilla Persona

How to setup Askbot not to send the whole answer via e-mail?

Per question rss feed?

how do I disable showing country flags?

What are the steps to install askbot-categorizetags?

How can an admin create lots of tags all at once?

How to hide the option "minor edit (don't send alerts)"

Is it possible to convert a answer into a comment or vice versa?

Copyright Askbot, 2010-2011. Content on this site is licensed under a Creative Commons Attribution Share Alike 3.0 license.
Powered by Askbot version 0.7.54
( 2016-08-05 07:02:32 -0500 )edit
none